==> frailtypack_2.5.tar.gz: frailtypack/src/Adonnees.f90 <==
!!! Donnees pour Joint



!AD:sortie fortran
    module sortie
    integer,save::cptaux,cptcens,nb0recu
    double precision::moyrecu
    end module sortie
!AD:



    module donnees
    
    implicit none
    double precision,dimension(6)::cof
    double precision::stp,half,one,fpf
    double precision,dimension(20),save::x,w!The abscissas-weights : w = w(xk)*exp(xk)
    double precision,dimension(32),save::x1,w1!The abscissas-weights : w1 = w(xk)*exp(xk)
    double precision,dimension(20),save::x2,w2
    double precision,dimension(32),save::x3,w3

    DATA w/0.181080062419,0.422556767879,0.666909546702,0.91535237279, &
    1.1695397071,1.43135498624,1.7029811359,1.98701589585, &
    2.28663576323,2.60583465152,2.94978381794,3.32539569477, &
    3.74225636246,4.21424053477,4.76252016007,5.42172779036, &
    6.25401146407,7.38731523837,9.15132879607,12.8933886244/
    
    DATA x/0.070539889692,0.372126818002,0.916582102483,1.70730653103, &
    2.74919925531,4.04892531384,5.61517497087,7.45901745389, &
    9.59439286749,12.0388025566,14.8142934155,17.9488955686, &
    21.4787881904,25.4517028094,29.9325546634,35.0134341868, &
    40.8330570974,47.6199940299,55.8107957541,66.5244165252/
    
    data cof,stp/76.18009173d0,-86.50532033d0,24.01409822d0, &
    -1.231739516d0,.120858003d-2,-.536382d-5,2.50662827465d0/
    data half,one,fpf/0.5d0,1.0d0,5.5d0/
    
    DATA w1/0.114187105768,0.266065216898,0.418793137325,0.572532846497, &
    0.727648788453,0.884536718946,1.04361887597,1.20534920595, &
    1.37022171969,1.53877595906,1.71164594592,1.8895649683, &
    2.07318851235,2.26590144444,2.46997418988,2.64296709494, &
    2.76464437462,3.22890542981,2.92019361963,4.3928479809, &
    4.27908673189,5.20480398519,5.11436212961,4.15561492173, &
    6.19851060567,5.34795780128,6.28339212457,6.89198340969, &
    7.92091094244,9.20440555803,11.1637432904,15.3902417688/
    
    DATA x1/0.0444893658333,0.23452610952,0.576884629302,1.07244875382, &
    1.72240877644,2.52833670643,3.49221327285,4.61645677223, &
    5.90395848335,7.3581268086,8.98294126732,10.783012089, &
    12.763745476,14.9309117981,17.2932661372,19.8536236493, &
    22.6357789624,25.6201482024,28.8739336869,32.3333294017, &
    36.1132042245,40.1337377056,44.5224085362,49.2086605665, &
    54.3501813324,59.8791192845,65.9833617041,72.6842683222, &
    80.1883747906,88.735192639,98.8295523184,111.751398227/

! gauss-hermite quadrature a 20 noeuds
    DATA w2/0.898591961453,0.704332961176,0.62227869619,0.575262442852, &
    0.544851742366,0.524080350949,0.509679027117,0.499920871336, &
    0.493843385272,0.490921500667,0.490921500667,0.493843385272, &
    0.499920871336,0.509679027117,0.524080350949,0.544851742366, &
    0.575262442852,0.62227869619,0.704332961176,0.898591961453/

    DATA x2/-5.38748089001,-4.60368244955,-3.94476404012,-3.34785456738, &
    -2.78880605843,-2.25497400209,-1.73853771212,-1.2340762154, &
    -0.737473728545,-0.245340708301,0.245340708301,0.737473728545, &
    1.2340762154,1.73853771212,2.25497400209,2.78880605843, &
    3.34785456738,3.94476404012,4.60368244955,5.38748089001/

! gauss-hermite quadrature a 32 noeuds
    DATA w3/0.824566523071,0.640950485906,0.561749015435,0.515037283347,0.48357144163, &
    0.460786455454,0.443553185862,0.430163710393,0.419597752949,0.411206128685, &
    0.404557061809,0.399354844618,0.395393939396,0.392531864366,0.390672744629, &
    0.389757342027,0.389757342027,0.390672744629,0.392531864366,0.395393939396, &
    0.399354844618,0.404557061809,0.411206128685,0.419597752949,0.430163710393, &
    0.443553185862,0.460786455454,0.48357144163,0.515037283347,0.561749015435, &
    0.640950485906,0.824566523071/

    DATA x3/-7.12581390983,-6.40949814928,-5.81222594946,-5.27555098664,-4.77716450334, &
    -4.30554795347,-3.85375548542,-3.41716749282,-2.99249082501,-2.57724953773, &
    -2.16949918361,-1.76765410946,-1.37037641095,-0.97650046359,-0.584978765436, &
    -0.194840741569,0.194840741569,0.584978765436,0.97650046359,1.37037641095, &
    1.76765410946,2.16949918361,2.57724953773,2.99249082501,3.41716749282, &
    3.85375548542,4.30554795347,4.77716450334,5.27555098664,5.81222594946, &
    6.40949814928,7.12581390983/
    
    end module donnees
!=======================================================================================
!=======================================================================================
!                                FIN marq98 version optim
!=======================================================================================
!=======================================================================================

==> frailtypack_2.7.1.tar.gz: frailtypack/src/Adonnees.f90 <==
!!! Donnees pour Joint

!AD:sortie fortran
    module sortie
    integer,save::cptaux,cptcens,nb0recu
    double precision::moyrecu
    end module sortie
!AD:

    module donnees
    
    implicit none
    double precision,dimension(6)::cof
    double precision::stp,half,one,fpf
    double precision,dimension(20),save::x,w   !The abscissas-weights : w = w(x)*exp(x)
    double precision,dimension(32),save::x1,w1 !The abscissas-weights : w1 = w(x1)*exp(x1)
    double precision,dimension(20),save::x2,w2 !The abscissas-weights : w2 = w(x2)*exp(x2*x2)
    double precision,dimension(32),save::x3,w3 !The abscissas-weights : w3 = w(x3)*exp(x3*x3)

    DATA w/0.181080062419,0.422556767879,0.666909546702,0.91535237279, &
    1.1695397071,1.43135498624,1.7029811359,1.98701589585, &
    2.28663576323,2.60583465152,2.94978381794,3.32539569477, &
    3.74225636246,4.21424053477,4.76252016007,5.42172779036, &
    6.25401146407,7.38731523837,9.15132879607,12.8933886244/
    
    DATA x/0.070539889692,0.372126818002,0.916582102483,1.70730653103, &
    2.74919925531,4.04892531384,5.61517497087,7.45901745389, &
    9.59439286749,12.0388025566,14.8142934155,17.9488955686, &
    21.4787881904,25.4517028094,29.9325546634,35.0134341868, &
    40.8330570974,47.6199940299,55.8107957541,66.5244165252/
    
    data cof,stp/76.18009173d0,-86.50532033d0,24.01409822d0, &
    -1.231739516d0,.120858003d-2,-.536382d-5,2.50662827465d0/
    data half,one,fpf/0.5d0,1.0d0,5.5d0/
    
    DATA w1/0.114187105768,0.266065216898,0.418793137325,0.572532846497, &
    0.727648788453,0.884536718946,1.04361887597,1.20534920595, &
    1.37022171969,1.53877595906,1.71164594592,1.8895649683, &
    2.07318851235,2.26590144444,2.46997418988,2.64296709494, &
    2.76464437462,3.22890542981,2.92019361963,4.3928479809, &
    4.27908673189,5.20480398519,5.11436212961,4.15561492173, &
    6.19851060567,5.34795780128,6.28339212457,6.89198340969, &
    7.92091094244,9.20440555803,11.1637432904,15.3902417688/
    
    DATA x1/0.0444893658333,0.23452610952,0.576884629302,1.07244875382, &
    1.72240877644,2.52833670643,3.49221327285,4.61645677223, &
    5.90395848335,7.3581268086,8.98294126732,10.783012089, &
    12.763745476,14.9309117981,17.2932661372,19.8536236493, &
    22.6357789624,25.6201482024,28.8739336869,32.3333294017, &
    36.1132042245,40.1337377056,44.5224085362,49.2086605665, &
    54.3501813324,59.8791192845,65.9833617041,72.6842683222, &
    80.1883747906,88.735192639,98.8295523184,111.751398227/

! gauss-hermite quadrature a 20 noeuds
    DATA w2/0.898591961453,0.704332961176,0.62227869619,0.575262442852, &
    0.544851742366,0.524080350949,0.509679027117,0.499920871336, &
    0.493843385272,0.490921500667,0.490921500667,0.493843385272, &
    0.499920871336,0.509679027117,0.524080350949,0.544851742366, &
    0.575262442852,0.62227869619,0.704332961176,0.898591961453/

    DATA x2/-5.38748089001,-4.60368244955,-3.94476404012,-3.34785456738, &
    -2.78880605843,-2.25497400209,-1.73853771212,-1.2340762154, &
    -0.737473728545,-0.245340708301,0.245340708301,0.737473728545, &
    1.2340762154,1.73853771212,2.25497400209,2.78880605843, &
    3.34785456738,3.94476404012,4.60368244955,5.38748089001/

! gauss-hermite quadrature a 32 noeuds
    DATA w3/0.824566523071,0.640950485906,0.561749015435,0.515037283347,0.48357144163, &
    0.460786455454,0.443553185862,0.430163710393,0.419597752949,0.411206128685, &
    0.404557061809,0.399354844618,0.395393939396,0.392531864366,0.390672744629, &
    0.389757342027,0.389757342027,0.390672744629,0.392531864366,0.395393939396, &
    0.399354844618,0.404557061809,0.411206128685,0.419597752949,0.430163710393, &
    0.443553185862,0.460786455454,0.48357144163,0.515037283347,0.561749015435, &
    0.640950485906,0.824566523071/

    DATA x3/-7.12581390983,-6.40949814928,-5.81222594946,-5.27555098664,-4.77716450334, &
    -4.30554795347,-3.85375548542,-3.41716749282,-2.99249082501,-2.57724953773, &
    -2.16949918361,-1.76765410946,-1.37037641095,-0.97650046359,-0.584978765436, &
    -0.194840741569,0.194840741569,0.584978765436,0.97650046359,1.37037641095, &
    1.76765410946,2.16949918361,2.57724953773,2.99249082501,3.41716749282, &
    3.85375548542,4.30554795347,4.77716450334,5.27555098664,5.81222594946, &
    6.40949814928,7.12581390983/
    
    end module donnees
!=======================================================================================
!=======================================================================================
!                                FIN marq98 version optim
!=======================================================================================
!=======================================================================================
